const { Client, GatewayIntentBits, Collection } = require('discord.js');
const express = require('express');
const Sequelize = require('sequelize');
const dotenv = require('dotenv');
const fs = require('node:fs');
const path = require('node:path');

dotenv.config();


// Configure database
const sequelize = new Sequelize('polarcraft', 'user', process.env.DATABSE_PASSWORD, {
  host: 'localhost',
  dialect: 'sqlite',
  logging: false,
  // SQLite only
  storage: 'database.sqlite',
});

exports.sequelize = sequelize;


// Configure Discord
const client = new Client({ intents: [GatewayIntentBits.Guilds, GatewayIntentBits.GuildVoiceStates, GatewayIntentBits.GuildMembers, GatewayIntentBits.GuildMessages, GatewayIntentBits.MessageContent] });
exports.client = client;

client.commands = new Collection();

const commandsPath = path.join(__dirname, 'commands');
const commandFiles = fs.readdirSync(commandsPath).filter(file => file.endsWith('.js'));

for (const file of commandFiles) {
  const filePath = path.join(commandsPath, file);
  const command = require(filePath);

  if ('data' in command && 'execute' in command) {
    client.commands.set(command.data.name, command);
  } else {
    console.log(`[WARNING] The command at ${filePath} is missing a required "data" or "execute" property.`);
  }
}

const eventsPath = path.join(__dirname, 'events');
const eventFiles = fs.readdirSync(eventsPath).filter(file => file.endsWith('.js'));

for (const file of eventFiles) {
  const filePath = path.join(eventsPath, file);
  const event = require(filePath);
  if (event.once) {
    client.once(event.name, (...args) => event.execute(...args));
  } else {
    client.on(event.name, (...args) => event.execute(...args));
  }
}


// Configure express
const app = express();
app.use(express.json());

const verifyMinecraftRoute = require('./routes/verifyminecraft');
const messageRoute = require('./routes/message');

app.use('/verifyminecraft', verifyMinecraftRoute);
app.use('/message', messageRoute);

app.listen('3000', () => {
  console.log('Express app is running');
});

client.login(process.env.DISCORD_TOKEN);

